@@ -3,9 +3,8 @@ use strict;
 use warnings;
 
 use if $ENV{USER} eq 'gene', lib => map { "$ENV{HOME}/sandbox/$_/lib" } qw(MIDI-Util);
-use if $ENV{USER} eq 'gene', lib => map { "$ENV{HOME}/repos/$_/lib" } qw(MIDI-RtMidi-FFI);
 
-use MIDI::RtMidi::FFI::ScorePlayer ();
+use MIDI::RtMidi::ScorePlayer ();
 use MIDI::Util qw( setup_score set_chan_patch );
 use Music::Scales qw( get_scale_MIDI );
 
